Struct dis_spawner::SessionLivedBackendStatus
source · [−]pub struct SessionLivedBackendStatus {
pub submitted: Option<bool>,
pub scheduled: Option<bool>,
pub running: Option<bool>,
pub ready: Option<bool>,
pub swept: Option<bool>,
pub node_name: Option<String>,
pub ip: Option<String>,
pub port: Option<u16>,
pub url: Option<String>,
}Fields
submitted: Option<bool>Set to true by spawner once the backing resources (pod and service) have been created.
scheduled: Option<bool>Set to true by spawner once the backing pod has been assigned to a node.
running: Option<bool>Set to true by spawner once the backing pod is observed in the Running state.
ready: Option<bool>Set to true by sweeper once the sidecar proxy issues an event with ready
set to true.
swept: Option<bool>Set to true by sweeper once the pod is observed to be inactive (per sidecar
events) for at least its grace period. This marks the SessionLivedBackend for
deletion by spawner.
node_name: Option<String>ip: Option<String>port: Option<u16>url: Option<String>Trait Implementations
sourceimpl Clone for SessionLivedBackendStatus
impl Clone for SessionLivedBackendStatus
sourcefn clone(&self) -> SessionLivedBackendStatus
fn clone(&self) -> SessionLivedBackendStatus
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for SessionLivedBackendStatus
impl Debug for SessionLivedBackendStatus
sourceimpl Default for SessionLivedBackendStatus
impl Default for SessionLivedBackendStatus
sourcefn default() -> SessionLivedBackendStatus
fn default() -> SessionLivedBackendStatus
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for SessionLivedBackendStatus
impl<'de> Deserialize<'de> for SessionLivedBackendStatus
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for SessionLivedBackendStatus
impl JsonSchema for SessionLivedBackendStatus
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<SessionLivedBackendStatus> for SessionLivedBackendStatus
impl PartialEq<SessionLivedBackendStatus> for SessionLivedBackendStatus
sourcefn eq(&self, other: &SessionLivedBackendStatus) -> bool
fn eq(&self, other: &SessionLivedBackendStatus) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &SessionLivedBackendStatus) -> bool
fn ne(&self, other: &SessionLivedBackendStatus) -> bool
This method tests for !=.
sourceimpl Serialize for SessionLivedBackendStatus
impl Serialize for SessionLivedBackendStatus
impl StructuralPartialEq for SessionLivedBackendStatus